Background estimation
=====================

.. *Documentation from* :file:`background.py`

background.py
-------------

.. automodule:: fretbursts.background

.. autofunction:: exp_fit

.. autofunction:: exp_cdf_fit

.. autofunction:: exp_hist_fit


Low-level background fit functions
----------------------------------

.. automodule:: fretbursts.fit.exp_fitting
    :members: